@@ -16,7 +16,7 @@ from obs.ilog import LogConf
 from obs.client import ObsClient
 from obs.model import CompletePart, Permission, StorageClass, EventType, RestoreTier, Group, Grantee, Grant
 from obs.model import ExtensionGrant, Owner, ACL, Condition, DateTime, SseCHeader, SseKmsHeader, CopyObjectHeader
-from obs.model import SetObjectMetadataHeader, CorsRule, CreateBucketHeader, ErrorDocument, IndexDocument, Expiration
+from obs.model import SetObjectMetadataHeader,RenameFileHeader, CorsRule, CreateBucketHeader, ErrorDocument, IndexDocument, Expiration
 from obs.model import NoncurrentVersionExpiration, GetObjectHeader, HeadPermission, Lifecycle, Notification
 from obs.model import TopicConfiguration, FunctionGraphConfiguration, FilterRule, Replication, ReplicationRule
 from obs.model import Options, PutObjectHeader, AppendObjectHeader, AppendObjectContent, RedirectAllRequestTo
@@ -49,6 +49,7 @@ __all__ = [
     'SseKmsHeader',
     'CopyObjectHeader',
     'SetObjectMetadataHeader',
+    'RenameFileHeader',
     'CorsRule',
     'CreateBucketHeader',
     'ErrorDocument',
